@@ -5,4 +5,4 @@ from dagster_ssh.version import __version__
 
 DagsterLibraryRegistry.register("dagster-ssh", __version__)
 
-__all__ = ["ssh_resource", "SSHResource"]
+__all__ = ["SSHResource", "ssh_resource"]
